summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/hwp/fapiTestHwpConfig.C
diff options
context:
space:
mode:
authorBill Schwartz <whs@us.ibm.com>2013-03-15 06:38:07 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-04-02 14:43:57 -0500
commit3521ec3d8f4de7ccedb0e7f1c0cd1f8910010189 (patch)
tree8159d8a627e53c0d504df205f09ec003f8f49dee /src/usr/hwpf/hwp/fapiTestHwpConfig.C
parent9062d2e331cc59c987d64f086bd4d979cee921b1 (diff)
downloadtalos-hostboot-3521ec3d8f4de7ccedb0e7f1c0cd1f8910010189.tar.gz
talos-hostboot-3521ec3d8f4de7ccedb0e7f1c0cd1f8910010189.zip
FAPI Interface to get the target on the other side of the Mem Channel - 2
Code review updates found during adding to the FSP side Change-Id: Idf3a37f1449a8c2abae994ab1b8107203212189b RTC:61987 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/3579 Tested-by: Jenkins Server Reviewed-by: ADAM R. MUHLE <armuhle@us.ibm.com> Reviewed-by: MIKE J. JONES <mjjones@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwpf/hwp/fapiTestHwpConfig.C')
-rw-r--r--src/usr/hwpf/hwp/fapiTestHwpConfig.C10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/usr/hwpf/hwp/fapiTestHwpConfig.C b/src/usr/hwpf/hwp/fapiTestHwpConfig.C
index f01811356..6ada488c8 100644
--- a/src/usr/hwpf/hwp/fapiTestHwpConfig.C
+++ b/src/usr/hwpf/hwp/fapiTestHwpConfig.C
@@ -112,7 +112,7 @@ fapi::ReturnCode hwpTestConfig(const fapi::Target & i_chip)
break;
}
// Call fapiGetOtherSideOfDmiBus to get mem buffer
fapi::Target l_mb;
fapi::Target l_mcs2;
@@ -121,23 +121,23 @@ fapi::ReturnCode hwpTestConfig(const fapi::Target & i_chip)
l_rc = fapiGetOtherSideOfMemChannel(l_mcs, l_mb);
if (l_rc)
{
- FAPI_ERR("hwpTestConfig: Error from fapiGetOtherSideOfDmiBus");
+ FAPI_ERR("hwpTestConfig: Error from fapiGetOtherSideOfMemChannel");
break;
}
FAPI_INF("hwpTestConfig: mem buf: %s", l_mb.toEcmdString());
// Call fapiGetOtherSideOfDmiBus to get back to the same mcs
l_rc = fapiGetOtherSideOfMemChannel(l_mb, l_mcs2);
if (l_rc)
{
- FAPI_ERR("hwpTestConfig: Error from fapiGetOtherSideOfDmiBus");
+ FAPI_ERR("hwpTestConfig: Error from fapiGetOtherSideOfMemChannel");
break;
}
FAPI_INF("hwpTestConfig: mcs: %s", l_mcs2.toEcmdString());
if (l_mcs != l_mcs2)
{
- FAPI_ERR("hwpTestConfig: fapiGetOtherSideOfDmiBus wrong mcs");
+ FAPI_ERR("hwpTestConfig: fapiGetOtherSideOfMemChannel wrong mcs");
FAPI_SET_HWP_ERROR(l_rc, RC_TEST_WRONG_MCS_RETURNED);
break;
}
@@ -112,7 +112,7 @@ fapi::ReturnCode hwpTestConfig(const fapi::Target & i_chip)
break;
}
- // Call fapiGetOtherSideOfDmiBus to get mem buffer
+ // Call fapiGetOtherSideOfMemChannel to get mem buffer
fapi::Target l_mb;
fapi::Target l_mcs2;
@@ -121,23 +121,23 @@ fapi::ReturnCode hwpTestConfig(const fapi::Target & i_chip)
}
FAPI_INF("hwpTestConfig: mem buf: %s", l_mb.toEcmdString());
- // Call fapiGetOtherSideOfDmiBus to get back to the same mcs
+ // Call fapiGetOtherSideOfMemChannel to get back to the same mcs
l_rc = fapiGetOtherSideOfMemChannel(l_mb, l_mcs2);
if (l_rc)
OpenPOWER on IntegriCloud